@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: hhalign_wrapper.c 260 2011-09-01 16:10:46Z fabian $
+ *  RCS $Id: hhalign_wrapper.c 267 2011-10-24 09:49:27Z fabian $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,6 +41,20 @@
 
 #define TRACE 0
 
+/**
+ * @brief FIXME
+ * 
+ * @note prHalignPara has tp point to an already allocated instance
+ *
+ */
+void SetDefaultHhalignPara(hhalign_para *prHhalignPara)
+{
+    prHhalignPara->iMacRamMB = 2048; /* give 2GB to MAC algorithm */
+}
+/*** end: SetDefaultHhalignPara()  ***/
+
+
+
 /**
  * @brief get rid of unknown residues
  *
@@ -523,7 +537,8 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
     StopwatchZero(stopwatch);
     StopwatchStart(stopwatch);
 #endif
-    
+    hhalign_scores rHHscores = {0};
+
     
     if (NULL != prHMMList) {
         if (iHMMCount>1) {
@@ -743,7 +758,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                                          ppcCopy1, piLeafCount[iL], pdWeightsL,
                                          &dScore, prHMM,
                                          NULL, NULL, NULL, NULL,
-                                         rHhalignPara, 
+                                         rHhalignPara, &rHHscores, 
                                          iAux_FS++, /* DEBUG ARGUMENT */
                                          zcAux, zcError);
                     }
@@ -752,7 +767,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                                          ppcReprsnt1, 0/* only one representative seq*/, NULL,
                                          &dScore, prHMM,
                                          NULL, NULL, NULL, NULL,
-                                         rHhalignPara, 
+                                         rHhalignPara, &rHHscores, 
                                          iAux_FS++, /* DEBUG ARGUMENT */
                                          zcAux, zcError);
                     }
@@ -830,7 +845,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                                          ppcCopy2,    piLeafCount[iR], pdWeightsR,
                                          &dScore, prHMM,
                                          NULL, NULL, NULL, NULL,
-                                         rHhalignPara, 
+                                         rHhalignPara, &rHHscores, 
                                          iAux_FS++, /* DEBUG ARGUMENT */
                                          zcAux, zcError);
                     }
@@ -839,7 +854,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                                          ppcReprsnt2, 0/* only one representative seq */, NULL,
                                          &dScore, prHMM,
                                          NULL, NULL, NULL, NULL,
-                                         rHhalignPara, 
+                                         rHhalignPara, &rHHscores, 
                                          iAux_FS++, /* DEBUG ARGUMENT */
                                          zcAux, zcError);
                     }
@@ -910,7 +925,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                                      &dScore, prHMM,
                                      pcConsens1, pcReprsnt1,
                                      pcConsens2, pcReprsnt2,
-                                     rHhalignPara, 
+                                     rHhalignPara, &rHHscores, 
                                      iAux_FS++, /* DEBUG ARGUMENT */
                                      zcAux, zcError);
 
@@ -946,7 +961,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                                          &dScore, prHMM,
                                          pcConsens1, pcReprsnt1,
                                          pcConsens2, pcReprsnt2,
-                                         rHhalignPara, 
+                                         rHhalignPara, &rHHscores, 
                                          iAux_FS++, /* DEBUG ARGUMENT */
                                          zcAux, zcError);
                         if (RETURN_OK != iHHret){ /* at this stage hhalign() has failed twice, 
@@ -971,7 +986,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                                      &dScore, prHMM,
                                      pcConsens2, pcReprsnt2,
                                      pcConsens1, pcReprsnt1,
-                                     rHhalignPara, 
+                                     rHhalignPara, &rHHscores, 
                                      iAux_FS++, /* DEBUG ARGUMENT */
                                      zcAux, zcError);
 
@@ -999,7 +1014,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                                          &dScore, prHMM,
                                          pcConsens2, pcReprsnt2,
                                          pcConsens1, pcReprsnt1,
-                                         rHhalignPara, 
+                                         rHhalignPara, &rHHscores, 
                                          iAux_FS++, /* DEBUG ARGUMENT */
                                          zcAux, zcError);
                         if (RETURN_OK != iHHret){ /* at this stage hhalign() has failed twice, 
@@ -1016,7 +1031,34 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
                     } /* 1st invocation failed */
 
                 } /* 2nd profile was shorter than 1st */
-                
+            
+                if (rLog.iLogLevelEnabled <= LOG_DEBUG){
+                    int i;
+
+                    printf("@@iL=%d, #(iL)=%d, iR=%d, #(iR)=%d\n", iL, piLeafCount[iL], iR, piLeafCount[iR]);
+                    for (i = 0; i < piLeafCount[iL]; i++){
+                        char *pc = ppcProfile1[i];
+                        printf("@@>%s\n", prMSeq->sqinfo[ppiLeafList[iL][i]].name);
+                        printf("@@");
+                        while('\0' != *pc){
+                            printf("%c", toupper(*pc));
+                            pc++;
+                        }
+                        printf("\n");
+                    }
+                    for (i = 0; i < piLeafCount[iR]; i++){
+                        char *pc = ppcProfile2[i];
+                        printf("@@>%s\n", prMSeq->sqinfo[ppiLeafList[iR][i]].name);
+                        printf("@@");
+                        while('\0' != *pc){
+                            printf("%c", toupper(*pc));
+                            pc++;
+                        }
+                        printf("\n");
+                    }
+                    printf("\n");
+                } /* LOG_DEBUG */    
+
             }
             /* free left/right node lists,
              * after alignment left/right profiles no longer needed
@@ -1042,7 +1084,7 @@ HHalignWrapper(mseq_t *prMSeq, int *piOrderLR,
             ppiLeafList[iL] = CKFREE(ppiLeafList[iL]);
             ppiLeafList[iR] = CKFREE(ppiLeafList[iR]);
             piLeafCount[iL] = piLeafCount[iR] = 0;
-
+            
         } /* was a merge node */
 
         if (rLog.iLogLevelEnabled <= LOG_DEBUG){
