@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: seq.c 258 2011-07-25 16:23:23Z andreas $
+ *  RCS $Id: seq.c 270 2011-11-16 07:27:31Z andreas $
  *
  *
  * Module for sequence/alignment IO and misc.
@@ -39,8 +39,7 @@
 #include "seq.h"
 
 
-#define ALLOW_ONLY_PROTEIN 0 /* requested by Hamish, FS, r244 -> r245 */
-
+#define ALLOW_ONLY_PROTEIN 1
 
 
 
@@ -366,17 +365,17 @@ LogSqInfo(SQINFO *sqinfo)
 
 
 /**
- * @brief convert int-encoded seqtype to string
+ * @brief convert int-encoded iSeqType to string
  *
- * @param[in] seqtype int-encoded sequence type
+ * @param[in] iSeqType int-encoded sequence type
  *
  * @return character pointer describing the sequence type
  *
  */
 const char*
-SeqTypeToStr(int seqtype)
+SeqTypeToStr(int iSeqType)
 {
-    switch (seqtype)  {
+    switch (iSeqType)  {
     case SEQTYPE_DNA:
         return "DNA";
     case SEQTYPE_RNA:
@@ -390,7 +389,7 @@ SeqTypeToStr(int seqtype)
     }
     return "Will never get here";
 }
-/***   end: seqtype_to_str   ***/
+/***   end: SeqTypeToStr   ***/
 
 
 
@@ -402,7 +401,7 @@ SeqTypeToStr(int seqtype)
  * FIXME: would make more sense to allocate it here.
  * @param[in] seqfile
  * Sequence file name. If '-' sequence will be read from stdin. 
- * @param[in] seqtype
+ * @param[in] iSeqType
  * int-encoded sequence type. Set to
  * SEQTYPE_UNKNOWN for autodetect (guessed from first sequence)
  * @param[in] iMaxNumSeq
@@ -418,10 +417,10 @@ SeqTypeToStr(int seqtype)
  *  - If supported by squid, gzipped files can be read as well.
  */
 int
-ReadSequences(mseq_t *prMSeq, char *seqfile, int seqtype,
+ReadSequences(mseq_t *prMSeq, char *seqfile, 
+              int iSeqType, int iSeqFmt,
               int iMaxNumSeq, int iMaxSeqLen)
 {
-    int fmt = SQFILE_UNKNOWN; /* file format: auto detect if unknown */
     SQFILE *dbfp; /* sequence file descriptor */
     char *cur_seq;
     SQINFO cur_sqinfo;
@@ -434,9 +433,9 @@ ReadSequences(mseq_t *prMSeq, char *seqfile, int seqtype,
     /* Try to work around inability to autodetect from a pipe or .gz:
      * assume FASTA format
      */
-    if (SQFILE_UNKNOWN == fmt  &&
+    if (SQFILE_UNKNOWN == iSeqFmt  &&
         (Strparse("^.*\\.gz$", seqfile, 0) || strcmp(seqfile, "-") == 0)) {
-        fmt = SQFILE_FASTA;
+        iSeqFmt = SQFILE_FASTA;
     }
   
     /* Using squid routines to read input. taken from seqstat_main.c. we don't
@@ -447,7 +446,7 @@ ReadSequences(mseq_t *prMSeq, char *seqfile, int seqtype,
      *
      */
 
-    if (NULL == (dbfp = SeqfileOpen(seqfile, fmt, NULL))) {
+    if (NULL == (dbfp = SeqfileOpen(seqfile, iSeqFmt, NULL))) {
         Log(&rLog, LOG_ERROR, "Failed to open sequence file %s for reading", seqfile);
         return -1;
     }
@@ -522,15 +521,15 @@ ReadSequences(mseq_t *prMSeq, char *seqfile, int seqtype,
             /* override with given sequence type but check with
              * automatically detected type and warn if necessary
              */
-            if (SEQTYPE_UNKNOWN != seqtype) {
-                if (prMSeq->seqtype != seqtype) { 
+            if (SEQTYPE_UNKNOWN != iSeqType) {
+                if (prMSeq->seqtype != iSeqType) { 
                     Log(&rLog, LOG_WARN, "Overriding automatically determined seq-type %s to %s as requested",
-                         SeqTypeToStr(prMSeq->seqtype), SeqTypeToStr(seqtype));
-                    prMSeq->seqtype = seqtype;
+                         SeqTypeToStr(prMSeq->seqtype), SeqTypeToStr(iSeqType));
+                    prMSeq->seqtype = iSeqType;
                 }
             }
             /* if type could not be determined and was not set return error */
-            if (SEQTYPE_UNKNOWN == seqtype && SEQTYPE_UNKNOWN == prMSeq->seqtype) {
+            if (SEQTYPE_UNKNOWN == iSeqType && SEQTYPE_UNKNOWN == prMSeq->seqtype) {
                 Log(&rLog, LOG_ERROR, "Couldn't guess sequence type from first sequence");
                 FreeSequence(cur_seq, &cur_sqinfo);        
                 SeqfileClose(dbfp);
