@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: hhalign.cpp 260 2011-09-01 16:10:46Z fabian $
+ *  RCS $Id: hhalign.cpp 267 2011-10-24 09:49:27Z fabian $
  */
 
 /* hhalign.C: 
@@ -670,6 +670,8 @@ ProcessArguments(int argc, char** argv)
  * @param[in] rHhalignPara,
  * various parameters passed down from commandline
  * e.g., iMaxRamMB
+ * @param[out] rHHscores
+ * qualify goodness of alignment
  *
  * iFlag,zcAux,zcError are debugging arguments
  *
@@ -681,7 +683,7 @@ hhalign(char **ppcFirstProf, int iFirstCnt, double *pdWeightsL,
         double *dScore_p, hmm_light *prHMM,
         char *pcPrealigned1, char *pcRepresent1, 
         char *pcPrealigned2, char *pcRepresent2, 
-        hhalign_para rHhalignPara, 
+        hhalign_para rHhalignPara, hhalign_scores *rHHscores, 
         int iFlag,
         char zcAux[], char zcError[]) {
 
@@ -1299,7 +1301,16 @@ hhalign(char **ppcFirstProf, int iFirstCnt, double *pdWeightsL,
                      q.name,t.name,par.hitrank,hit.score,hit.Pval);
       }
   
-  
+  rHHscores->hhScore     = hit.score; 
+  rHHscores->forwardProb = hit.Pforward;
+  rHHscores->sumPP       = hit.sum_of_probs;
+  rHHscores->PP = (double *)malloc((hit.L+GOOD_MEASURE) * sizeof(double));
+  rHHscores->L  = hit.L;
+  for (int i = 0; i < hit.L; i++){
+      rHHscores->PP[i] = hit.P_posterior[i+1];
+  }
+
+
  this_is_the_end: 
 
   // Delete memory for dynamic programming matrix
