@@ -15,7 +15,7 @@
  ********************************************************************/
 
 /*
- *  RCS $Id: mymain.c 263 2011-09-07 14:54:19Z dave $
+ *  RCS $Id: mymain.c 270 2011-11-16 07:27:31Z andreas $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -36,9 +36,6 @@
 
 #include "mymain.h"
 
-/* hhalign (parameters) */
-#include "hhalign/general.h"
-
 typedef struct {
 
     /* Sequence input
@@ -51,6 +48,10 @@ typedef struct {
      * info for background-HMM creation */
     bool bDealignInputSeqs;
 
+    /** Sequence input format
+     */
+    int iSeqInFormat;
+
     /* profiles: : pre-aligned sequences, whose alignment will not be changed 
      */
     /** profile 1: pre-aligned sequence input. not directly used by Align() */
@@ -95,6 +96,12 @@ typedef struct {
 /* log-file used for non-essential logging in prLog */
 FILE *prLogFile = NULL;
 
+const char *CITATION = " Sievers F, Wilm A, Dineen D, Gibson TJ, Karplus K, Li W, Lopez R, McWilliam H, Remmert M, Söding J, Thompson JD, Higgins DG."
+    "\n"
+    " Fast, scalable generation of high-quality protein multiple sequence alignments using Clustal Omega."
+    "\n"
+    " Mol Syst Biol. 2011 Oct 11;7:539. doi: 10.1038/msb.2011.75. PMID: 21988835.";
+
 
 
 /**
@@ -107,7 +114,6 @@ FILE *prLogFile = NULL;
 void
 SetDefaultUserOpts(cmdline_opts_t *opts)
 {
-
     assert(NULL != opts);
 
     opts->iSeqType = SEQTYPE_UNKNOWN;
@@ -148,7 +154,8 @@ PrintUserOpts(FILE *prFile, cmdline_opts_t *opts) {
     
     /* keep in same order as in struct. FIXME could this be derived from argtable?
      */
-    /* we only allow protein anyway: fprintf(prFile, "seq-type = %s\n", SeqTypeToStr(opts->iSeqType)); */
+    fprintf(prFile, "seq-type = %s\n", SeqTypeToStr(opts->iSeqType));
+    fprintf(prFile, "seq-in-fmt = %s\n", SeqfileFormat2String(opts->iSeqInFormat));
     fprintf(prFile, "option: seq-in = %s\n", 
             NULL != opts->pcSeqInfile? opts->pcSeqInfile: "(null)");
     fprintf(prFile, "option: dealign = %d\n", opts->bDealignInputSeqs);
@@ -246,6 +253,8 @@ UserOptsLogicCheck(cmdline_opts_t *opts)
     if ( (NULL != opts->aln_opts.pcDistmatOutfile) && (TRUE == opts->aln_opts.bUseMbed) ) {
         Log(&rLog, LOG_FATAL, "Distance Matrix output not possible in mBed mode.");
     }
+
+    AlnOptsLogicCheck(& opts->aln_opts);
 }
 /* end of UserOptsLogicCheck */
 
@@ -290,15 +299,23 @@ ParseCommandLine(cmdline_opts_t *user_opts, int argc, char **argv)
                                             "HMM input files");
     struct arg_lit *opt_dealign = arg_lit0(NULL, "dealign",
                                            "Dealign input sequences");
-    struct arg_str *opt_seqtype = arg_str0("t", "seqtype",
-                                           "{Protein,RNA,DNA}",
-                                           "Force a sequence type (default: auto)");
     struct arg_file *opt_profile1 = arg_file0(NULL, "profile1,p1",
                                               "<file>",
                                               "Pre-aligned multiple sequence file (aligned columns will be kept fix)");
     struct arg_file *opt_profile2 = arg_file0(NULL, "profile2,p2",
                                               "<file>",
                                               "Pre-aligned multiple sequence file (aligned columns will be kept fix)");
+#if 0
+    struct arg_str *opt_seqtype = arg_str0("t", "seqtype",
+                                           "{Protein, RNA, DNA}",
+                                           "Force a sequence type (default: auto)");
+#else
+    struct arg_lit *opt_force_protein = arg_lit0(NULL, "protein",
+                                         "Set sequence type to protein even if Clustal guessed nucleic acid");
+#endif
+    struct arg_str *opt_infmt = arg_str0(NULL, "infmt",
+                                            "{a2m=fa[sta],clu[stal],msf,phy[lip],selex,st[ockholm],vie[nna]}",
+                                            "Forced sequence input file format (default: auto)");
 
     
     struct arg_rem  *rem_guidetree  = arg_rem(NULL, "\nClustering:");
@@ -391,13 +408,15 @@ ParseCommandLine(cmdline_opts_t *user_opts, int argc, char **argv)
                         opt_seqin,
                         opt_hmm_in,
                         opt_dealign,
+                        opt_profile1,
+                        opt_profile2,
 #if 0
                         /* unused since we only support protein for now */
                         opt_seqtype,
+#else
+                        opt_force_protein,
 #endif
-                        opt_profile1,
-                        opt_profile2,
-
+                        opt_infmt,
                         rem_guidetree,
 #if 0
                         /* no other options then default available or not implemented */
@@ -456,14 +475,12 @@ ParseCommandLine(cmdline_opts_t *user_opts, int argc, char **argv)
     if (opt_help->count > 0) {
         printf("%s - %s (%s)\n", PACKAGE_NAME, PACKAGE_VERSION, PACKAGE_CODENAME);
 
+        printf("\n");
+        printf("If you like Clustal-Omega please cite:\n%s\n", CITATION);
+        printf("If you don't like Clustal-Omega, please let us know why (and cite us anyway).\n");
+        /* printf("You can contact reach us under %s\n", PACKAGE_BUGREPORT); */
         printf("\n");
         printf("Check http://www.clustal.org for more information and updates.\n");
-
-        /*printf("\n");
-          printf("FIXME more info e.g. how it works, pointers to references etc...\n");
-          FIXME which paper to cite etc
-        */
-
             
         printf("\n");
         printf("Usage: %s", basename(argv[0]));
@@ -590,8 +607,20 @@ ParseCommandLine(cmdline_opts_t *user_opts, int argc, char **argv)
         user_opts->iMaxSeqLen = opt_max_seqlen->ival[0];
     }
     
+    /* Output format
+     */
+    if (opt_infmt->count > 0) {
+        /* avoid gcc warning about discarded qualifier */
+        char *tmp = (char *)opt_infmt->sval[0];
+        user_opts->iSeqInFormat = String2SeqfileFormat(tmp);
+    } else {
+        user_opts->iSeqInFormat = SQFILE_UNKNOWN;
+    }
+
+
     /* Sequence type
      */
+#if 0
     if (opt_seqtype->count > 0) {
         if (STR_NC_EQ(opt_seqtype->sval[0], "protein")) {
             user_opts->iSeqType = SEQTYPE_PROTEIN;
@@ -603,6 +632,11 @@ ParseCommandLine(cmdline_opts_t *user_opts, int argc, char **argv)
             Log(&rLog, LOG_FATAL, "Unknown sequence type '%s'", opt_seqtype->sval[0]);
         }
     }
+#else
+    if (opt_force_protein->count > 0) {
+        user_opts->iSeqType = SEQTYPE_PROTEIN;
+    }
+#endif
 
     /* Profile input
      */
@@ -807,11 +841,9 @@ ParseCommandLine(cmdline_opts_t *user_opts, int argc, char **argv)
     /* max MAC RAM (maximum amount of RAM set aside for MAC algorithm)
      */
     if (opt_macram->count > 0) { /* FS, r240 -> r241 */
-        user_opts->aln_opts.iMacRam = opt_macram->ival[0];
+        user_opts->aln_opts.rHhalignPara.iMacRamMB = opt_macram->ival[0];
     }
 
-
-
     arg_freetable(argtable,sizeof(argtable)/sizeof(argtable[0]));
 
     UserOptsLogicCheck(user_opts);
@@ -835,7 +867,6 @@ MyMain(int argc, char **argv)
     mseq_t *prMSeqProfile1 = NULL;
     mseq_t *prMSeqProfile2 = NULL;
     cmdline_opts_t cmdline_opts;
-    hhalign_para rHhalignPara = {0};
 
     /* Must happen first: setup logger */
     LogDefaultSetup(&rLog);
@@ -860,10 +891,6 @@ MyMain(int argc, char **argv)
         PrintUserOpts(LogGetFP(&rLog, LOG_INFO), & cmdline_opts);
         PrintAlnOpts(LogGetFP(&rLog, LOG_INFO), & (cmdline_opts.aln_opts));
     }
-    /* write relevant command-line options for hhalign
-     *
-     */
-    rHhalignPara.iMacRamMB = cmdline_opts.aln_opts.iMacRam;
 
     /* Read sequence file
      *
@@ -871,7 +898,7 @@ MyMain(int argc, char **argv)
     if (NULL != cmdline_opts.pcSeqInfile) {
         NewMSeq(&prMSeq);
         if (ReadSequences(prMSeq, cmdline_opts.pcSeqInfile,
-                          cmdline_opts.iSeqType,
+                          cmdline_opts.iSeqType, cmdline_opts.iSeqInFormat,
                           cmdline_opts.iMaxNumSeq, cmdline_opts.iMaxSeqLen)) {
             Log(&rLog, LOG_FATAL, "Reading sequence file '%s' failed", cmdline_opts.pcSeqInfile);
         }
@@ -910,7 +937,7 @@ MyMain(int argc, char **argv)
     if (NULL != cmdline_opts.pcProfile1Infile) {
         NewMSeq(&prMSeqProfile1);
         if (ReadSequences(prMSeqProfile1, cmdline_opts.pcProfile1Infile,
-                          cmdline_opts.iSeqType,
+                          cmdline_opts.iSeqType,  cmdline_opts.iSeqInFormat,
                           cmdline_opts.iMaxNumSeq, cmdline_opts.iMaxSeqLen)) {
             Log(&rLog, LOG_FATAL, "Reading sequences from profile file '%s' failed",
                   cmdline_opts.pcProfile1Infile);
@@ -935,7 +962,7 @@ MyMain(int argc, char **argv)
     if (NULL != cmdline_opts.pcProfile2Infile) {
         NewMSeq(&prMSeqProfile2);
         if (ReadSequences(prMSeqProfile2, cmdline_opts.pcProfile2Infile,
-                          cmdline_opts.iSeqType,
+                          cmdline_opts.iSeqType,  cmdline_opts.iSeqInFormat,
                           cmdline_opts.iMaxNumSeq, cmdline_opts.iMaxSeqLen)) {
             Log(&rLog, LOG_FATAL, "Reading sequences from profile file '%s' failed",
                   cmdline_opts.pcProfile2Infile);
@@ -965,7 +992,7 @@ MyMain(int argc, char **argv)
      *
      */
     if (NULL != prMSeq) {
-        if (Align(prMSeq, prMSeqProfile1, & cmdline_opts.aln_opts, rHhalignPara)) {
+        if (Align(prMSeq, prMSeqProfile1, & cmdline_opts.aln_opts)) {
             Log(&rLog, LOG_FATAL, "An error occured during the alignment");
         }
 
@@ -983,7 +1010,8 @@ MyMain(int argc, char **argv)
         
 
     } else if (NULL != prMSeqProfile1 && NULL != prMSeqProfile2) {
-        if (AlignProfiles(prMSeqProfile1, prMSeqProfile2, rHhalignPara)) {
+        if (AlignProfiles(prMSeqProfile1, prMSeqProfile2, 
+                          cmdline_opts.aln_opts.rHhalignPara)) {
             Log(&rLog, LOG_FATAL, "An error occured during the alignment");
         }
         if (WriteAlignment(prMSeqProfile1, cmdline_opts.pcAlnOutfile, 
